#
# spec file for package ghc-pretty-simple
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name pretty-simple
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        4.1.3.0
Release:        1.3
Summary:        Pretty printer for data types with a 'Show' instance
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-optparse-applicative-prof
BuildRequires:  ghc-prettyprinter-ansi-terminal-devel
BuildRequires:  ghc-prettyprinter-ansi-terminal-prof
BuildRequires:  ghc-prettyprinter-devel
BuildRequires:  ghc-prettyprinter-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}

%description
Pretty printer for data types with a 'Show' instance.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%{_bindir}/%{pkg_name}

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Dec  8 2024 Peter Simons <psimons@suse.com>
- Update pretty-simple to version 4.1.3.0.
  [#]# 4.1.3.0
  * Remove custom setup. This makes cross-compiling `pretty-simple` a lot more
    straightforward. No functionality has been lost from the library, since the
    custom setup was only used for generating tests.
    [#107](https://github.com/cdepillabout/pretty-simple/pull/107)
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sat Oct 15 2022 Peter Simons <psimons@suse.com>
- Update pretty-simple to version 4.1.2.0.
  [#]# 4.1.2.0
  * Fix a problem with the `pHPrint` function incorrectly
    outputting a trailing newline to stdout, instead of the
    handle you pass it.
    [#118](https://github.com/cdepillabout/pretty-simple/pull/118)
  * Add a [web app](https://cdepillabout.github.io/pretty-simple/) where you
    can play around with `pretty-simple` in your browser.
    [#116](https://github.com/cdepillabout/pretty-simple/pull/116).
    This took a lot of hard work by [@georgefst](https://github.com/georgefst)!
  [#]# 4.1.1.0
  * Make the pretty-printed output with `outputOptionsCompact` enabled a little
    more compact.
    [#110](https://github.com/cdepillabout/pretty-simple/pull/110).
    Thanks [@juhp](https://github.com/juhp)!
  * Add a `--compact` / `-C` flag to the `pretty-simple` executable that enables
    `outputOptionsCompact`.
    [#111](https://github.com/cdepillabout/pretty-simple/pull/111).
    Thanks again @juhp!
  * Add `pTraceWith` and `pTraceShowWith` to `Debug.Pretty.Simple`.
    [#104](https://github.com/cdepillabout/pretty-simple/pull/104).
    Thanks [@LeviButcher](https://github.com/LeviButcher)!
  [#]# 4.1.0.0
  * Fix a regression which arose in 4.0, whereby excess spaces would be inserted for unusual strings like dates and IP addresses.
    [#105](https://github.com/cdepillabout/pretty-simple/pull/105)
  * Attach warnings to debugging functions, so that they're easy to find and remove.
    [#103](https://github.com/cdepillabout/pretty-simple/pull/103)
  * Some minor improvements to the CLI tool:
  * Add a `--version`/`-v` flag.
    [#83](https://github.com/cdepillabout/pretty-simple/pull/83)
  * Add a trailing newline.
    [#87](https://github.com/cdepillabout/pretty-simple/pull/87)
  * Install by default, without requiring a flag.
    [#94](https://github.com/cdepillabout/pretty-simple/pull/94)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Sep 15 2020 psimons@suse.com
- Update pretty-simple to version 4.0.0.0.
  [#]# 4.0.0.0
  * Expand `OutputOptions`:
  * Compactness, including grouping of parentheses.
    [#72](https://github.com/cdepillabout/pretty-simple/pull/72)
  * Page width, affecting when lines are grouped if compact output is enabled.
    [#72](https://github.com/cdepillabout/pretty-simple/pull/72)
  * Indent whole expression. Useful when using `pretty-simple` for one part
    of a larger output.
    [#71](https://github.com/cdepillabout/pretty-simple/pull/71)
  * Use `Style` type for easier configuration of colour, boldness etc.
    [#73](https://github.com/cdepillabout/pretty-simple/pull/73)
  * Significant internal rewrite of printing code, to make use of the [prettyprinter](https://hackage.haskell.org/package/prettyprinter)
    library. The internal function `layoutString` can be used to integrate with
    other `prettyprinter` backends, such as [prettyprinter-lucid](https://hackage.haskell.org/package/prettyprinter-lucid)
    for HTML output.
    [#67](https://github.com/cdepillabout/pretty-simple/pull/67)
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Wed Jul  8 2020 psimons@suse.com
- Add pretty-simple at version 3.3.0.0.
